%module neighbors

%{
#include "libharkio3.h"
#include "libharkio3_macros.h"
#define HARKIO_LOG_INITIAL_LEVEL harkio_Log_Error

%}

typedef struct{
    int size;                       /*!< 隣接関係を表したいPositionの数 */
    int *ids;                       /*!< 隣接関係を表したいPositionのidのリスト */
    int *numNeighbors;              /*!< Positionごとの、隣接するPositionの個数 */
    int **neighbors;                /*!< Positionごとの、隣接するPositionのidのリスト */
    harkio_Positions *poses;        /*!< 隣接関係が表す Posisition のリスト   */
    enum NeighborAlgorithm alg;     /*!< 隣接関係を求めるアルゴリズム */
} harkio_Neighbors;

harkio_Neighbors* harkio_Neighbors_new(harkio_Positions *poses);
harkio_Neighbors* harkio_Neighbors_copy(harkio_Neighbors *poses);
void harkio_Neighbors_delete(harkio_Neighbors **nbrs);

int harkio_Neighbors_calcNeighbors(harkio_Neighbors *nbrs, enum NeighborAlgorithm alg, ...);
int harkio_Neighbors_getNeighbors(harkio_Neighbors *nbrs, int id, int *numNeighbors, int **neighbors);
int harkio_Neighbors_append(harkio_Neighbors *nbrs, int id, int numNeighbors, int *neighbors);
int harkio_Neighbors_getSize(harkio_Neighbors *nbs );
enum NeighborAlgorithm harkio_Neighbors_getNeighborAlgorithm(harkio_Neighbors *nbs);

int harkio_Neighbors_Algorithms_NearestNeighbor(harkio_Neighbors *nbrs, int n, float thresh);
void harkio_Neighbors_print(harkio_Neighbors *nbrs);

int harkio_Neighbors_isEqual(harkio_Neighbors* a, harkio_Neighbors *b);